@@ -483,114 +483,103 @@ def Entropy(v, env):
 
 
 #    void py_FuzzyMeasureFit(int datanum, int additive, struct fm_env* env, double* out_v, double* dataset)
-def FuzzyMeasureFit(datanum, additive, env, dataset = None):
+def FuzzyMeasureFit(datanum, additive, env, dataset):
     trace( "void py_FuzzyMeasureFit(int datanum, int additive, struct fm_env* env, double* out_v, double* dataset)")
     pout_vnp, pout_v = create_float_zeros_as_CFFI_double( env.m)
-    if dataset == None: dataset = np.random.rand(datanum, env.n + 1)
     pdatasetnp, pdataset = convert_py_float_to_cffi( dataset)
     fm.py_FuzzyMeasureFit( datanum, additive, env, pout_v, pdataset)
-    return pout_vnp, dataset
+    return pout_vnp
 
 
 
 #    void py_FuzzyMeasureFitMob(int datanum, int additive, struct fm_env* env, double* out_v, double* dataset)
-def FuzzyMeasureFitMob(datanum, additive, env, dataset = None):
+def FuzzyMeasureFitMob(datanum, additive, env, dataset):
     trace( "void py_FuzzyMeasureFitMob(int datanum, int additive, struct fm_env* env, double* out_v, double* dataset)")
     pout_vnp, pout_v = create_float_zeros_as_CFFI_double( env.m)
-    if dataset == None: dataset = np.random.rand(datanum, env.n + 1)
     pdatasetnp, pdataset = convert_py_float_to_cffi( dataset)
     fm.py_FuzzyMeasureFitMob( datanum, additive, env, pout_v, pdataset)
-    return pout_vnp, dataset
+    return pout_vnp
 
 
 
 #    void py_FuzzyMeasureFitKtolerant(int datanum, int additive, struct fm_env* env, double* out_v, double* dataset)
-def FuzzyMeasureFitKtolerant(datanum, additive, env, dataset = None):
+def FuzzyMeasureFitKtolerant(datanum, additive, env, dataset):
     trace( "void py_FuzzyMeasureFitKtolerant(int datanum, int additive, struct fm_env* env, double* out_v, double* dataset)")
     pout_vnp, pout_v = create_float_zeros_as_CFFI_double( env.m)
-    if dataset == None: dataset = np.random.rand(datanum, env.n + 1)
     pdatasetnp, pdataset = convert_py_float_to_cffi( dataset)
     fm.py_FuzzyMeasureFitKtolerant( datanum, additive, env, pout_v, pdataset)
-    return pout_vnp, dataset
+    return pout_vnp
 
 
 
 #    void py_FuzzyMeasureFitLPKmaxitive(int datanum, int additive, struct fm_env* env, double* out_v, double* dataset)
-def FuzzyMeasureFitLPKmaxitive(datanum, additive, env, dataset = None):
+def FuzzyMeasureFitLPKmaxitive(datanum, additive, env, dataset):
     trace( "void py_FuzzyMeasureFitLPKmaxitive(int datanum, int additive, struct fm_env* env, double* out_v, double* dataset)")
     pout_vnp, pout_v = create_float_zeros_as_CFFI_double( env.m)
-    if dataset == None: dataset = np.random.rand(datanum, env.n + 1)
     pdatasetnp, pdataset = convert_py_float_to_cffi( dataset)
     fm.py_FuzzyMeasureFitLPKmaxitive( datanum, additive, env, pout_v, pdataset)
-    return pout_vnp, dataset
+    return pout_vnp
 
 
 
 #    void py_FuzzyMeasureFitLPKinteractive(int datanum, int additive, struct fm_env* env, double* out_v, double* dataset, double* K)
-def FuzzyMeasureFitLPKinteractive(datanum, additive, env, K, dataset = None):
+def FuzzyMeasureFitLPKinteractive(datanum, additive, env, K, dataset):
     trace( "void py_FuzzyMeasureFitLPKinteractive(int datanum, int additive, struct fm_env* env, double* out_v, double* dataset, double* K)")
     pout_vnp, pout_v = create_float_zeros_as_CFFI_double( env.m)
-    if dataset == None: dataset = np.random.rand(datanum, env.n + 1)
     pdatasetnp, pdataset = convert_py_float_to_cffi( dataset)
     pKnp, pK = convert_py_float_to_cffi( K)
     fm.py_FuzzyMeasureFitLPKinteractive( datanum, additive, env, pout_v, pdataset, pK)
-    return pout_vnp, dataset
+    return pout_vnp
 
 
 
 #    void py_FuzzyMeasureFitLPKinteractiveMaxChains(int datanum, int additive, struct fm_env* env, double* out_v, double* dataset, double* K)
-def FuzzyMeasureFitLPKinteractiveMaxChains(datanum, additive, env, K, dataset = None):
-    trace( "void py_FuzzyMeasureFitLPKinteractiveMaxChains(int datanum, int additive, struct fm_env* env, double* out_v, double* dataset = None, double* K)")
+def FuzzyMeasureFitLPKinteractiveMaxChains(datanum, additive, env, K, dataset):
+    trace( "void py_FuzzyMeasureFitLPKinteractiveMaxChains(int datanum, int additive, struct fm_env* env, double* out_v, double* dataset, double* K)")
     pout_vnp, pout_v = create_float_zeros_as_CFFI_double( env.m)
-    if dataset == None: dataset = np.random.rand(datanum, env.n + 1)
     pdatasetnp, pdataset = convert_py_float_to_cffi( dataset)
     pKnp, pK = convert_py_float_to_cffi( K)
     fm.py_FuzzyMeasureFitLPKinteractiveMaxChains( datanum, additive, env, pout_v, pdataset, pK)
-    return pout_vnp, dataset
+    return pout_vnp
 
 
 
 #    void py_FuzzyMeasureFitLPKinteractiveAutoK(int datanum, int additive, struct fm_env* env, double* out_v, double* dataset, double* K, int* maxiters)
-def FuzzyMeasureFitLPKinteractiveAutoK(datanum, additive, env, K, maxiters, dataset = None):
+def FuzzyMeasureFitLPKinteractiveAutoK(datanum, additive, env, K, maxiters, dataset):
     trace( "void py_FuzzyMeasureFitLPKinteractiveAutoK(int datanum, int additive, struct fm_env* env, double* out_v, double* dataset, double* K, int* maxiters)")
     pout_vnp, pout_v = create_float_zeros_as_CFFI_double( env.m)
-    if dataset == None: dataset = np.random.rand(datanum, env.n + 1)
     pdatasetnp, pdataset = convert_py_float_to_cffi( dataset)
     pKnp, pK = convert_py_float_to_cffi( K)
     pmaxitersnp, pmaxiters = convert_py_int_to_cffi( maxiters)
     fm.py_FuzzyMeasureFitLPKinteractiveAutoK( datanum, additive, env, pout_v, pdataset, pK, pmaxiters)
-    return pout_vnp, dataset
+    return pout_vnp
 
 
 
 #    void py_FuzzyMeasureFitLPKinteractiveMarginal(int datanum, int additive, struct fm_env* env, double* out_v, double* dataset, double* K, int submod)
-def FuzzyMeasureFitLPKinteractiveMarginal(datanum, additive, env, K, submod, dataset = None):
+def FuzzyMeasureFitLPKinteractiveMarginal(datanum, additive, env, K, submod, dataset):
     trace( "void py_FuzzyMeasureFitLPKinteractiveMarginal(int datanum, int additive, struct fm_env* env, double* out_v, double* dataset, double* K, int submod)")
     pout_vnp, pout_v = create_float_zeros_as_CFFI_double( env.m)
-    if dataset == None: dataset = np.random.rand(datanum, env.n + 1)
     pdatasetnp, pdataset = convert_py_float_to_cffi( dataset)
     pKnp, pK = convert_py_float_to_cffi( K)
     fm.py_FuzzyMeasureFitLPKinteractiveMarginal( datanum, additive, env, pout_v, pdataset, pK, submod)
-    return pout_vnp, dataset
+    return pout_vnp
 
 #    void py_FuzzyMeasureFitLPKinteractiveMarginalMaxChain(int datanum, int additive, struct fm_env* env, double* out_v, double* dataset, double* K, int* maxiters, int submod)
-def FuzzyMeasureFitLPKinteractiveMarginalMaxChain(datanum, additive, env, K, maxiters, submod, dataset = None):
+def FuzzyMeasureFitLPKinteractiveMarginalMaxChain(datanum, additive, env, K, maxiters, submod, dataset):
     trace( "void py_FuzzyMeasureFitLPKinteractiveMarginalMaxChain(int datanum, int additive, struct fm_env* env, double* out_v, double* dataset, double* K, int* maxiters, int submod)")
     pout_vnp, pout_v = create_float_zeros_as_CFFI_double( env.m)
-    if dataset == None: dataset = np.random.rand(datanum, env.n + 1)
     pdatasetnp, pdataset = convert_py_float_to_cffi( dataset)
     pKnp, pK = convert_py_float_to_cffi( K)
     pmaxitersnp, pmaxiters = convert_py_int_to_cffi( maxiters)
     fm.py_FuzzyMeasureFitLPKinteractiveMarginalMaxChain( datanum, additive, env, pout_v, pdataset, pK, pmaxiters, submod)
-    return pout_vnp, dataset
-
+    return pout_vnp
 
 
 #    void py_FuzzyMeasureFitLP(int datanum, int additive, struct fm_env* env, double* out_v, double* dataset, int* options, double* indexlow, double* indexhihg, int* option1, double* orness)
-def FuzzyMeasureFitLP(datanum, additive, env, options, indexlow, indexhihg, option1, orness, dataset = None):
+def FuzzyMeasureFitLP(datanum, additive, env, options, indexlow, indexhihg, option1, orness, dataset):
     trace( "void py_FuzzyMeasureFitLP(int datanum, int additive, struct fm_env* env, double* out_v, double* dataset, int* options, double* indexlow, double* indexhihg, int* option1, double* orness)")
     pout_vnp, pout_v = create_float_zeros_as_CFFI_double( env.m)
-    if dataset == None: dataset = np.random.rand(datanum, env.n + 1)
     pdatasetnp, pdataset = convert_py_float_to_cffi( dataset)
     poptionsnp, poptions = convert_py_int_to_cffi( options)
     pindexlownp, pindexlow = convert_py_float_to_cffi( indexlow)
@@ -598,15 +587,13 @@ def FuzzyMeasureFitLP(datanum, additive, env, options, indexlow, indexhihg, opti
     poption1np, poption1 = convert_py_int_to_cffi( option1)
     pornessnp, porness = convert_py_float_to_cffi( orness)
     fm.py_FuzzyMeasureFitLP( datanum, additive, env, pout_v, pdataset, poptions, pindexlow, pindexhihg, poption1, porness)
-    return pout_vnp, dataset
-
+    return pout_vnp
 
 
 #    void py_FuzzyMeasureFitLPMob(int datanum, int additive, struct fm_env* env, double* out_v, double* dataset, int* options, double* indexlow, double* indexhihg, int* option1, double* orness)
-def FuzzyMeasureFitLPMob(datanum, additive, env, options, indexlow, indexhihg, option1, orness, dataset = None):
+def FuzzyMeasureFitLPMob(datanum, additive, env, options, indexlow, indexhihg, option1, orness, dataset):
     trace( "void py_FuzzyMeasureFitLPMob(int datanum, int additive, struct fm_env* env, double* out_v, double* dataset, int* options, double* indexlow, double* indexhihg, int* option1, double* orness)")
     pout_vnp, pout_v = create_float_zeros_as_CFFI_double( env.m)
-    if dataset == None: dataset = np.random.rand(datanum, env.n + 1)
     pdatasetnp, pdataset = convert_py_float_to_cffi( dataset)
     poptionsnp, poptions = convert_py_int_to_cffi( options)
     pindexlownp, pindexlow = convert_py_float_to_cffi( indexlow)
@@ -614,31 +601,25 @@ def FuzzyMeasureFitLPMob(datanum, additive, env, options, indexlow, indexhihg, o
     poption1np, poption1 = convert_py_int_to_cffi( option1)
     pornessnp, porness = convert_py_float_to_cffi( orness)
     fm.py_FuzzyMeasureFitLPMob( datanum, additive, env, pout_v, pdataset, poptions, pindexlow, pindexhihg, poption1, porness)
-    return pout_vnp, dataset
-
+    return pout_vnp
 
 
 #    void py_fittingOWA(int datanum, struct fm_env* env, double* out_v, double* dataset)
-def fittingOWA(datanum, env, dataset = None):
+def fittingOWA(datanum, env, dataset):
     trace( "void py_fittingOWA(int datanum, struct fm_env* env, double* out_v, double* dataset)")
     pout_vnp, pout_v = create_float_zeros_as_CFFI_double( env.m)
-    if dataset == None: dataset = np.random.rand(datanum, env.n + 1)
     pdatasetnp, pdataset = convert_py_float_to_cffi( dataset)
     fm.py_fittingOWA( datanum, env, pout_v, pdataset)
     return pout_vnp, dataset
 
 
-
 #    void py_fittingWAM(int datanum, struct fm_env* env, double* out_v, double* dataset)
-def fittingWAM(datanum, env, dataset = None):
+def fittingWAM(datanum, env, dataset):
     trace( "void py_fittingWAM(int datanum, struct fm_env* env, double* out_v, double* dataset)")
     pout_vnp, pout_v = create_float_zeros_as_CFFI_double( env.m)
-    if dataset == None: dataset = np.random.rand(datanum, env.n + 1)
     pdatasetnp, pdataset = convert_py_float_to_cffi( dataset)
     fm.py_fittingWAM( datanum, env, pout_v, pdataset)
-    return pout_vnp, dataset
-
-
+    return pout_vnp
 
 
 #    void py_Interaction(double* Mob, double* out_v, struct fm_env* env)
@@ -662,7 +643,6 @@ def InteractionB(Mob, env):
     return pout_vnp
 
 
-
 #    void py_InteractionMob(double* Mob, double* out_v, struct fm_env* env)
 def InteractionMob(Mob, env):
     trace( "void py_InteractionMob(double* Mob, double* out_v, struct fm_env* env)")
