@@ -244,7 +244,8 @@ print( "r: ", r)
 #    void py_FuzzyMeasureFit(int datanum, int additive, struct fm_env* env, double* out_v, double* dataset)
 datanum = 10
 additive = 2
-res, dataset = pyfm.FuzzyMeasureFit(datanum, additive, env, dataset = None)
+dataset = [random.random()] * datanum * ( env.n + 1)
+res = pyfm.FuzzyMeasureFit(datanum, additive, env, dataset)
 print( "datanum: ", datanum)
 print( "additive: ", additive)
 print( "dataset: ", dataset)
@@ -254,7 +255,8 @@ print( "res: ", res)
 #    void py_FuzzyMeasureFitMob(int datanum, int additive, struct fm_env* env, double* out_v, double* dataset)
 datanum = 10
 additive = 3
-res, dataset = pyfm.FuzzyMeasureFitMob(datanum, additive, env, dataset = None)
+dataset = [random.random()] * datanum * ( env.n + 1)
+res = pyfm.FuzzyMeasureFitMob(datanum, additive, env, dataset)
 print( "datanum: ", datanum)
 print( "additive: ", additive)
 print( "dataset: ", dataset)
@@ -264,7 +266,8 @@ print( "res: ", res)
 #    void py_FuzzyMeasureFitKtolerant(int datanum, int additive, struct fm_env* env, double* out_v, double* dataset)
 datanum = 10
 additive = 2
-res, dataset = pyfm.FuzzyMeasureFitKtolerant(datanum, additive, env, dataset = None)
+dataset = [random.random()] * datanum * ( env.n + 1)
+res = pyfm.FuzzyMeasureFitKtolerant(datanum, additive, env, dataset)
 print( "datanum: ", datanum)
 print( "additive: ", additive)
 print( "dataset: ", dataset)
@@ -274,7 +277,8 @@ print( "res: ", res)
 #    void py_FuzzyMeasureFitLPKmaxitive(int datanum, int additive, struct fm_env* env, double* out_v, double* dataset)
 datanum = 10
 additive = 2
-res, dataset = pyfm.FuzzyMeasureFitLPKmaxitive(datanum, additive, env, dataset = None)
+dataset = [random.random()] * datanum * ( env.n + 1)
+res = pyfm.FuzzyMeasureFitLPKmaxitive(datanum, additive, env, dataset)
 print( "datanum: ", datanum)
 print( "additive: ", additive)
 print( "dataset: ", dataset)
@@ -285,7 +289,8 @@ print( "res: ", res)
 datanum = 10
 additive = 2
 K = 0.5
-v, dataset = pyfm.FuzzyMeasureFitLPKinteractive(datanum, additive, env, K, dataset = None)
+dataset = [random.random()] * datanum * ( env.n + 1)
+v = pyfm.FuzzyMeasureFitLPKinteractive(datanum, additive, env, K, dataset)
 print( "datanum: ", datanum)
 print( "additive: ", additive)
 print( "K: ", K)
@@ -298,7 +303,8 @@ print( "v: ", v)
 datanum = 10
 additive = 2
 K = 0.5
-v, dataset = pyfm.FuzzyMeasureFitLPKinteractiveMaxChains(datanum, additive, env, K, dataset = None)
+dataset = [random.random()] * datanum * ( env.n + 1)
+v = pyfm.FuzzyMeasureFitLPKinteractiveMaxChains(datanum, additive, env, K, dataset)
 print( "datanum: ", datanum)
 print( "additive: ", additive)
 print( "K: ", K)
@@ -311,7 +317,8 @@ datanum = 10
 additive = 2
 K = 0.5
 maxiters = 100
-v, dataset = pyfm.FuzzyMeasureFitLPKinteractiveAutoK(datanum, additive, env, K, maxiters, dataset = None)
+dataset = [random.random()] * datanum * ( env.n + 1)
+v = pyfm.FuzzyMeasureFitLPKinteractiveAutoK(datanum, additive, env, K, maxiters, dataset)
 print( "datanum: ", datanum)
 print( "additive: ", additive)
 print( "K: ", K)
@@ -325,8 +332,7 @@ datanum = 10
 additive = 2
 K = 0.5
 submod = 1
-dataset = [0] * datanum * ( env.n + 1)
-for i in range( 0, len( dataset)): dataset[i] = random.random()
+dataset = [random.random()] * datanum * ( env.n + 1)
 v = pyfm.FuzzyMeasureFitLPKinteractiveMarginal(datanum, additive, env,  K, submod, dataset)
 print( "datanum: ", datanum)
 print( "additive: ", additive)
@@ -341,7 +347,8 @@ datanum = 10
 additive = 2
 K = 0.5
 submod = 1
-v, dataset = pyfm.FuzzyMeasureFitLPKinteractiveMarginalMaxChain(datanum, additive, env, K, maxiters, submod, dataset = None)
+dataset = [random.random()] * datanum * ( env.n + 1)
+v = pyfm.FuzzyMeasureFitLPKinteractiveMarginalMaxChain(datanum, additive, env, K, maxiters, submod, dataset)
 print( "datanum: ", datanum)
 print( "additive: ", additive)
 print( "submod: ", submod)
@@ -353,12 +360,13 @@ print( "v: ", v)
 #    void py_FuzzyMeasureFitLP(int datanum, int additive, struct fm_env* env, double* out_v, double* dataset, int* options, double* indexlow, double* indexhihg, int* option1, double* orness)
 datanum = 10
 additive = 2
-options = [0]
+options = 0
 indexlow = [0, 0, 0]
 indexhihg = [1, 1, 1]
-option1 = [0]
-orness = [0.5]
-v, dataset = pyfm.FuzzyMeasureFitLP(datanum, additive, env, options, indexlow, indexhihg, option1, orness, dataset = None)
+option1 = 0
+orness = 0.5
+dataset = [random.random()] * datanum * ( env.n + 1)
+v = pyfm.FuzzyMeasureFitLP(datanum, additive, env, options, indexlow, indexhihg, option1, orness, dataset)
 print( "datanum: ", datanum)
 print( "additive: ", additive)
 print( "indexlow: ", indexlow)
@@ -373,12 +381,13 @@ print( "v: ", v)
 #    void py_FuzzyMeasureFitLPMob(int datanum, int additive, struct fm_env* env, double* out_v, double* dataset, int* options, double* indexlow, double* indexhihg, int* option1, double* orness)
 datanum = 10
 additive = 2
-options = [0]
+options = 0
 indexlow = [0, 0, 0]
 indexhihg = [1, 1, 1]
-option1 = [0]
-orness = [0.5]
-Mob, dataset = pyfm.FuzzyMeasureFitLPMob(datanum, additive, env, options, indexlow, indexhihg, option1, orness, dataset = None)
+option1 = 0
+orness = 0.5
+dataset = [random.random()] * datanum * ( env.n + 1)
+Mob = pyfm.FuzzyMeasureFitLPMob(datanum, additive, env, options, indexlow, indexhihg, option1, orness, dataset)
 print( "datanum: ", datanum)
 print( "additive: ", additive)
 print( "indexlow: ", indexlow)
@@ -393,7 +402,8 @@ print( "Mob: ", Mob)
 #    void py_fittingOWA(int datanum, struct fm_env* env, double* out_v, double* dataset)
 # documented, no example
 datanum = 10
-v , dataset = pyfm.fittingOWA(datanum, env, dataset = None)
+dataset = [random.random()] * datanum * ( env.n + 1)
+v = pyfm.fittingOWA(datanum, env, dataset)
 print( "datanum: ", datanum)
 print( "dataset: ", dataset)
 print( "v: ", v)
@@ -403,7 +413,8 @@ print( "v: ", v)
 # documented, no example
 datanum = 10
 atanum = 10
-v , dataset = pyfm.fittingWAM(datanum, env, dataset = None)
+dataset = [random.random()] * datanum * ( env.n + 1)
+v = pyfm.fittingWAM(datanum, env, dataset)
 print( "datanum: ", datanum)
 print( "dataset: ", dataset)
 print( "v: ", v)
